define([
    'components/phone_pwd/index',
    'api/my',
    'text!components/my/account/index.html',
    'css!components/my/account/index.css'
], function(PhonePwd, myApi, html) {
    return {
        components: {
            'phone-pwd': PhonePwd
        },
        filters: {
            phoneEncrypt: function (phone) {
                if (!phone) {
                    return '';
                }
                return phone.replace(/(\d{3})\d*(\d{4})/, '$1****$2');
            }
        },
        props: {
            isLogin: {
                type: Boolean,
                default: false
            },
            userInfo: {
                type: Object,
                default: function () {
                    return {};
                }
            }
        },
        data: function () {
            return {
                nicknameReadonly: true,
                phonePwdVisible: false,
                phonePwd: true,
                avatar: ''
            };
        },
        methods: {
            handleSuccess: function (res) {
                var vm = this;
                vm.avatar = res.data.url;
                vm.$message.success(res.msg);
            },
            // 点击保存
            save: function () {
                var vm = this;
                myApi.saveUserInfo({
                    avatar: this.avatar || this.userInfo.avatar,
                    nickname: this.userInfo.nickname
                }).then(function (res) {
                    vm.$message.success(res.msg);
                    vm.nicknameReadonly = true;
                    vm.$emit('update-user');
                }).catch(function (err) {
                    vm.$message.error(err.msg);
                });
            },
            phoneClose: function () {
                this.phonePwdVisible = false;
            },
            loginAgain: function () {
                this.phonePwdVisible = false;
                this.$emit('login-again');
            },
            // 点击头像的修改
            updateAvatar: function () {
                this.$refs.upload.$refs['upload-inner'].$refs.input.click();
            }
        },
        template: html
    };
});